@@ -8,12 +8,12 @@
 #' 
 #' @section A note on standard errors: Estimation of standard errors is done by repeated calculation of item parameters for subsamples of the given data. This procedure is mainly controlled by the arguments \code{nsample} and \code{size} (see arguments). With regard to calculation time, the argument \code{nsample} is the 'time killer'. On the other hand, things (estimation of standard errors) will not necessarily get better when choosing large values for \code{nsample}. For example choosing \code{nsample=400} will only result in minimal change for standard error estimation in comparison to (\code{nsample=30}) which is the default setting (see examples). 
 #'
-#' @param daten daten a data matrix with optionaly named colums (names of items) or a data.frame, potentially with missing values, comprising polytomous responses of respondents (rows) on some items (colums) coded starting with 0 for lowest category to \emph{m}-1 for highest category, with \emph{m} beeing the number of categories for all items.
-#' @param m number of response categories for all items - by default \emph{m} is defined as \code{m = max(daten,na.rm=TRUE)+1}.
+#' @param daten a data.frame or matrix with optionaly named colums (names of items), potentially with missing values, comprising polytomous or dichotomous (or mixted category numbers) responses of \code{n} respondents (rows) on \code{k} items (colums) coded starting with 0 for lowest category to \emph{m}-1 for highest category, with \emph{m} beeing a vector (with length k) with the number of categories for the respective item.
+#' @param m an integer (will be recycled to a vector of length k) or a vector giving the number of response categories for all items - by default \code{m = NULL}, \code{m} is calculated from data, assuming that every response category is at least once present in data. For sparse data it is strongly recomended to explicitly define the number of categories by defining this argument.
 #' 
 #' @param split Specifies the splitting criterion. Basically there are three different options available - each with several modes - which are controlled by passing the corresponding character expression to the argument. 
 #' 
-#' 1) Using the rawscore for splitting into subsamples with the following modes: \code{split = "median"} median raw score split - high score group and low score group; \code{split = "mean"} mean raw score split - high score group and low score group; \code{split = "score"} splitting \code{daten} into as many subsamples as there are raw score groups (discarding min and max score group) 
+#' 1) Using the rawscore for splitting into subsamples with the following modes: \code{split = "median"} median raw score split - high score group and low score group; \code{split = "mean"} mean raw score split - high score group and low score group.
 #' 
 #' 2) Dividing the persons in \code{daten} into subsamples with equal size by random allocation with the following modes: \code{split = "random"} (which is equivalent to \code{split = "random.2"}) divides persons into two subsamples with equal size. In general the number of desired subsamples must be expressed after the dot in the character expression - e.g. \code{split = "random.6"} divides persons into 6 subsamples (with equal size) by random allocation etc. 
 #' 
@@ -30,8 +30,14 @@
 #' 
 #' @examples data(bfiN) # loading example data set
 #' 
+#' data(bfi_cov) # loading covariates to bfiN data set
+#' 
 #' # calculating itemparameters and SE for two random allocated subsamples
-#' grm_med<-grm(daten=bfiN, split = "median")
+#' grm_gen <- grm(daten=bfiN, split = bfi_cov$gender)
+#' summary(grm_gen)
+#' plot(grm_gen)
+#' 
+#' grm_med <- grm(daten=bfiN, split = "median")
 #' summary(grm_med)
 #' plot(grm_med)
 #' 
@@ -69,7 +75,7 @@
 #' 
 ############## funktions beginn ########################################################
 
-grm<-function(daten, m=NULL, split="random", splitseed="no", verbose=TRUE, ...){ 
+grm<-function(daten, m=NULL, split="random", splitseed="no", verbose=FALSE, ...){ 
 #### abfragen der teilungskriterien und teiler vorbereiten
   teil <- split  # übergabe an internes argument
 if(!(length(teil) > 1)) {  
@@ -91,19 +97,19 @@ if(!(length(teil) > 1)) {
   if(teil=="mean"){
     daten<-as.matrix(daten)
     rscore<-rowSums(daten,na.rm = TRUE)
-    teiler<-factor(ifelse(rscore >= mean(rscore),"upper" ,"lower" ))
+    teiler<-factor(ifelse(rscore > round(mean(rscore)),"above mean" ,"mean and below" ))
     #OK
   }
   if(teil=="median"){
     daten<-as.matrix(daten)
     rscore<-rowSums(daten,na.rm = TRUE)
-    teiler<-factor(ifelse(rscore >= median(rscore),"upper" ,"lower" ))
+    teiler<-factor(ifelse(rscore > median(rscore),"above median" ,"median and below" ))
     #OK
   }
   
 }
   
-  if((class(teil)=="numeric") | (class(teil)=="factor")  ){
+  if((class(teil)=="integer") | (class(teil)=="numeric") | (class(teil)=="factor")){
     #teiler<-daten[,teil]
     if( (dim(daten)[1])!=length(teil) ){stop("length of argument 'split' dose not match with 'data'")}
     teiler<-teil
@@ -122,9 +128,9 @@ datalist<-vector("list",length=length(subsamp)) #vorber. leere datalist
  }
 names(datalist) <- paste(subsamp,"sample")
      
-     grm <- lapply(datalist, pairSE, m=m, verbose=verbose, ...) 
-     class(grm) <- c("grm","list")
+     erg <- lapply(datalist, pairSE, m=m, verbose=verbose, ...) 
+     class(erg) <- c("grm","list")
 
-  return(grm)
+  return(erg)
 # summary.grm(grm)
 }
