@@ -10,11 +10,12 @@ pvx.matrix<-function(theta_v,thres,xm_v=NULL){
   thres0<-c(0,thres)
   oben_v <- exp(apply((s%o%theta_v),2,function(x){x-cumsum(thres0)})) # ok - für theta_v als vector oder zahl
   unten_v<- apply( exp(apply((s%o%theta_v),2,function(x){x-cumsum(thres0)})) , 2 ,sum) # ok - für theta_v als vector oder zahl  
-  px_v <- mapply(FUN=function(o,u){  o / u }, o=as.list(as.data.frame(oben_v)), u=unten_v ) # ok - für theta_v als vector oder zahl
+  px_v <- mapply(FUN=function(o,u){  o / u }, o=as.list(as.data.frame(oben_v)), u=as.list(unten_v) ) # u as list etc --> korrigiert am 10-3-2015 # ok - für theta_v als vector oder zahl 
   rownames(px_v)<-paste("cat",0:(length(thres0)-1),sep=".") 
   colnames(px_v)<-theta_v 
   P_v <- apply(px_v,2,sum) # ok - für theta_v als vector oder zahl
   if(length(xm_v)==0){return( (px_v) )}
   if(length(xm_v)!=0){mapply(function(p,ic){p[ic]}, as.list(as.data.frame(px_v)), xm_v)}
 }     
-#---------------------------------------------------  
\ No newline at end of file
+#---------------------------------------------------  
+
